Struct amazon_sp_notifications::models::destination::Destination
source · [−]pub struct Destination {
pub name: String,
pub destination_id: String,
pub resource: Box<DestinationResource>,
}Expand description
Destination : Represents a destination created when you call the createDestination operation.
Fields
name: StringThe developer-defined name for this destination.
destination_id: StringThe destination identifier generated when you created the destination.
resource: Box<DestinationResource>Implementations
sourceimpl Destination
impl Destination
sourcepub fn new(
name: String,
destination_id: String,
resource: DestinationResource
) -> Destination
pub fn new(
name: String,
destination_id: String,
resource: DestinationResource
) -> Destination
Represents a destination created when you call the createDestination operation.